From 377e04ccc860fa77c07e2d4521b68c392119a2bf Mon Sep 17 00:00:00 2001
From: Daniel Tran <d.tran@adito.de>
Date: Fri, 6 Aug 2021 07:51:14 +0200
Subject: [PATCH] =?UTF-8?q?[Projekt:=20xRM-ContactManagement][TicketNr.:?=
 =?UTF-8?q?=201084172][Email=5Fentity=20=C3=BCbergibt=20an=20Dokuvorlagen?=
 =?UTF-8?q?=20Field=20anstatt=20Parameter]=20-=20Changed=20return=20value?=
 =?UTF-8?q?=20to=20$param.DocumentTemplateTypeClassification=5Fparam,=20to?=
 =?UTF-8?q?=20get=20the=20=20=20=20=20right=20doc-templates=20displayed.?=
 =?UTF-8?q?=20-=20Renamed=20param=20in=20function,=20to=20so=20more=20mean?=
 =?UTF-8?q?ingful.?=
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit

---
 .../valueProcess.js                                         | 2 +-
 process/Email_lib/process.js                                | 6 +++---
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/entity/Email_entity/entityfields/documenttemplates/children/documenttemplatetypeclassification_param/valueProcess.js b/entity/Email_entity/entityfields/documenttemplates/children/documenttemplatetypeclassification_param/valueProcess.js
index 1ee6655bba..70e703a7f3 100644
--- a/entity/Email_entity/entityfields/documenttemplates/children/documenttemplatetypeclassification_param/valueProcess.js
+++ b/entity/Email_entity/entityfields/documenttemplates/children/documenttemplatetypeclassification_param/valueProcess.js
@@ -1,4 +1,4 @@
 import("system.vars");
 import("system.result");
 
-result.string(vars.get("$field.documenttemplatetypeclassification"));
\ No newline at end of file
+result.string(vars.get("$param.DocumentTemplateTypeClassification_param"));
\ No newline at end of file
diff --git a/process/Email_lib/process.js b/process/Email_lib/process.js
index 71cabd93f6..7e2adcf0ba 100644
--- a/process/Email_lib/process.js
+++ b/process/Email_lib/process.js
@@ -92,10 +92,10 @@ EmailWritingUtils.openMailTemplate = function (pToRecipients, pSenderContactId,
  * @param {String} pEmailFilename optional file name of the email.
  * @param {String} [pAdditionalPlaceholders] additional placeholders for the email
  * @param {Array[]} [pUpdateStatements] an array with update statements which will be executed after email is downloaded/sent.
  * @param {String} pDocumentTemplateType The document template type (single or serial - <b><u><i>use keyword!</i></u></b>).
  */
 EmailWritingUtils.openNewMail = function (pToContactId, pToEmailAddress, pComingFrom, pAttachmentArray, pNotificationMsg, pEmailFilename, 
-                                                pAdditionalPlaceholders, pUpdateStatements, pDocumentTemplateType)
+                                                pAdditionalPlaceholders, pUpdateStatements, pDocumentTemplateTypeClassification)
 {
     var params = {
         "ContactId_param" : pToContactId,
@@ -105,7 +105,7 @@ EmailWritingUtils.openNewMail = function (pToContactId, pToEmailAddress, pComing
         "EmailFilename" : pEmailFilename,
         "AdditionalPlaceholders_param" : JSON.stringify(pAdditionalPlaceholders),
         "UpdateStatements_param" : JSON.stringify(pUpdateStatements),
-        "DocumentTemplateTypeClassification_param" : pDocumentTemplateType
+        "DocumentTemplateTypeClassification_param" : pDocumentTemplateTypeClassification
     };
     
     if (pToEmailAddress)
@@ -92,10 +92,10 @@ EmailWritingUtils.openMailTemplate = function (pToRecipients, pSenderContactId,
  * @param {String} [pAdditionalPlaceholders] additional placeholders for the email
  * @param {Array[]} [pUpdateStatements] an array with update statements which will be executed after email is downloaded/sent.
- * @param {String} pDocumentTemplateType The document template type (single or serial - <b><u><i>use keyword!</i></u></b>).
+ * @param {String} pDocumentTemplateTypeClassification The document template type classification.
  */
 EmailWritingUtils.openNewMail = function (pToContactId, pToEmailAddress, pComingFrom, pAttachmentArray, pNotificationMsg, pEmailFilename, 
-- 
GitLab